Praxis Seizure: Los Angeles Event #2 Los Angeles, California February 17th 2001 Darby Keeney https://groups.google.com/forum/#!msg/rec.games.trading-cards.jyhad/5Ta-UxWXDAI/25RQ-pg-4rgJ Deck Name: WeePee Bleed 101 Description & Playstyle: Concept and play are simple, BLEEEEED! Process: Try to influence 3-4 vampires out in the same turn, unless you're being no-stealth bleed for a bunch early. Pentex that big vampire your prey first influences after you've got your critters in a line. Attempt to bleed with enhancement. Use S:CE to tap out any Wakey blockers. Repeat process lots of times, using Propaganda & Anarch Troublemaker only when you think you can bleed your prey out. Hint: If you don't have S:CE in hand, consider bleeding anyway. Use Media Influence (sup) to refill anyone in torpor (it works on all controlled vampires), then rescue them and begin bleeding again. If you have too much S:CE, bleed anyway and hope for combat to clear your hand. Pool management is mostly from rapid ousting and can cause high stomach acid levels. Social Charm (sup), Enchant Kindred (sup) and Tribute to the Master followed by Media Influence (sup) can supplement when Tums(r) are insufficient. Deck is weakest against vote, steath bleed and weenie bleed decks. Possible offensive improvements/variants, depending on metagame: Pump bleed by using 4-8 Legal Manipulation replacing Social Charm and/or Tribute to the Master. Get slightly more deceitful - and nominally faster, by adding 1-4 more Aire of Elation, in place of Enchant Kindred. Add more tap effects with 1-2 Propaganda in place of Enchant Kindred or Possible defensive improvements/variants, depending on metagame: Substitute 1-2 Archon Investigation for Tribute to the Master. Consider 1-4 Delaying Tactics in place of Social Charm and/or Enchant Kindred. Crypt (16 cards, min=5, max=17, avg=2.75) ----------------------------------------- 1x Jost Werner 6 AUS PRE ani Toreador antitribu:2 1x Mariana Gilbert 4 PRE cel Toreador:1 1x Violette Prentiss 4 PRE dom Ventrue:1 1x Gideon Fontaine 3 PRE Ventrue:1 1x Itzahk Levine 3 cel pre Ventrue:2 1x Khalil Anvari 3 pre ser Follower of Set:2 1x Lena Rowe 3 aus obf pre Pander:2 1x Lolita 3 for pre Toreador antitribu:2 1x Roland Loussarian 3 for pre Ventrue:1 1x Uma Hatch 3 cel pre Brujah:1 1x Delilah Easton 2 pre Toreador:1 1x Frederick the Weak 2 pre Brujah antitribu:2 1x Vasilis, The Traitor of Don Cruez 2 pre Brujah:2 1x Angela Decker 1 pre Pander:2 1x Antoinette DuChamp 1 cel pre Caitiff:2 1x Igo the Hungry 1 pre pro Caitiff:1 Library (90 cards) Master (21) 3x Anarch Troublemaker 5x Effective Management 4x Pentex(TM) Subversion 3x Presence 6x Tribute to the Master Action (45) 9x Enchant Kindred 2x Entrancement 15x Media Influence 4x Propaganda 15x Social Charm Action Modifier (4) 4x Aire of Elation Combat (20) 6x Catatonic Fear 14x Majesty